@@ -44,7 +44,7 @@ int main(int argc, char **argv)
 
     const QString description = i18n("Plymouth theme installer");
 
-    app.setApplicationVersion(QStringLiteral(PLYMOUTH_KCM_VERSION));
+    app.setApplicationVersion(QStringLiteral(PROJECT_VERSION));
     parser.addVersionOption();
     parser.addHelpOption();
     parser.setApplicationDescription(description);
@@ -106,7 +106,7 @@ int main(int argc, char **argv)
             if (dir->entries().count() > 1) {
                 helperargs[QStringLiteral("theme")] = QFileInfo(archive->fileName()).baseName();
             } else {
-                helperargs[QStringLiteral("theme")] = dir->entries().first();
+                helperargs[QStringLiteral("theme")] = dir->entries().constFirst();
             }
         } else {
             helperargs[QStringLiteral("theme")] = themefile;
